=======
Credits
=======

Development Lead
----------------

* Stefan Ecklebe <stefan.ecklebe@tu-dresden.de>

Contributors
------------

* Christoph Burggraf
* Marcus Riesmeier
* Jonas Hoffmann
* Jens Wurm
* Simon Bachler
